@@ -49,21 +49,24 @@ name = 'sardana'
 #: the new substring. We have to avoid using either dashes or underscores,
 #: because bdist_rpm does not accept dashes (an RPM) convention, and
 #: bdist_deb does not accept underscores (a Debian convention).
-version_info = (1, 2, 0, 'rc', 0)
+version_info = (1, 4, 0, 'rc', 0)
 version = '.'.join(map(str, version_info[:3]))
 revision = str(version_info[4])
 
-description = "Sardana is a generic program for control applications in large and small installations"
-
-long_description = """Produce a modular, high performance, robust and generic user environment 
-for control applications in large and small installations. 
-Make Sardana the generic user environment distributed in the TANGO project 
-and the standard basis of collaborations in control."""
+description = "instrument control and data acquisition system"
 
+long_description = \
+'''Sardana is a Supervision, Control And Data Acquisition (SCADA) system for
+ scientific installations. It is written in Python and based on the TANGO
+ library. The hardware control and data acquisition routines can be
+ accessed via an IPython console and a generic graphical user interface
+ (both of which are easily extensible by the user).'''
+ 
 license = 'LGPL'
 
 authors = {'Tiago'          : ('Tiago Coutinho','tiago.coutinho@esrf.fr'),
-           'Pascual-Izarra' : ('Carlos Pascual-Izarra','cpascual@cells.es') }
+           'Pascual-Izarra' : ('Carlos Pascual-Izarra','cpascual@cells.es'),
+           'Reszela'        : ('Zbigniew Reszela','zreszela@cells.es') }
 
 url = 'http://packages.python.org/sardana'
 
